Tikki Repository
================

Tikki is the application for collection and management of field aptitude 
perfomance data of Finnish reservists. Key features are easy and fast result 
recording and controlled authorization of results. The development of the 
app is managed by Lisää liikettä program, led by the Finnish Reservist 
Sports Federation (RESUL).


`Learn more <https://github.com/tikki-fi/tikki>`_.
